/**************************************************************************
                       aggir.h  -  description
                         -------------------
        begin            : 2003-07-06
        copyright        : (C) 2003 by Grard Delafond & Joris Marcillac
        email            : gerard@delafond.org & joris@marcillac.com
**************************************************************************/
/**************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         * 
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
*   Library General Public License for more details.                      *
*                                                                         *
*   You should have received a copy of the GNU Library General Public     *
*   License along with this library; if not, write to the Free            *
*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,       *
*   MA 02111-1307, USA                                                    *
*                                                                         *
**************************************************************************/

class CAggir
{
public:
    CAggir();
    virtual ~CAggir();
    
    enum Note { A = 0, B = 1, C = 2 };
    
    void setCoherence( CAggir::Note code );
    void setOrientation( CAggir::Note code );    
    void setToilette( CAggir::Note code );
    void setHabillement( CAggir::Note code );
    void setAlimentation( CAggir::Note code );
    void setElimination( CAggir::Note code );
    void setTransfert( CAggir::Note code );
    void setDeplacementInterne( CAggir::Note code );
    void setDeplacementExterne( CAggir::Note code );
    void setCommunication( CAggir::Note code );
    
    int Gir( bool recalcul = true );
    void reinit();
    
private:
    void setCurrentByDataAGGIR( int code, int numRub );
    void setSigma();
    void setRang();
    bool isGroupA( int value );
    bool isGroupB( int value );
    bool isGroupC( int value );
    bool isGroupD( int value );
    bool isGroupE( int value );
    bool isGroupF( int value );
    bool isGroupG( int value );
    bool isGroupH( int value );
    void setGir();
    
    enum { note = 3, rub = 10, groupe = 8 };
    enum {Coherence = 0, Orientation, Toilette, Habillement, Alimentation, 
        Elimination, Transfert, DeplacementInterne, DeplacementExterne, Communication };
        
	static int dataAGGIR [note][rub][groupe];
	int current[rub][groupe];
	int sigma[groupe];
	int m_rang;
	int m_gir;
};

/*****************************************************************************
  inline functions
 *****************************************************************************/
inline void CAggir::setCoherence( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Coherence );
}

inline void CAggir::setOrientation( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Orientation );
}

inline void CAggir::setToilette( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Toilette );
}

inline void CAggir::setHabillement( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Habillement );
}

inline void CAggir::setAlimentation( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Alimentation );
}

inline void CAggir::setElimination( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Elimination );
}

inline void CAggir::setTransfert( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Transfert );
}

inline void CAggir::setDeplacementInterne( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, DeplacementInterne );
}

inline void CAggir::setDeplacementExterne( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, DeplacementExterne );
}

inline void CAggir::setCommunication( CAggir::Note code )
{
    setCurrentByDataAGGIR( code, Communication );
}


